@@ -157,7 +157,9 @@ TEST_P(DefaultChannelModeTest, LiveGetLocalhostByAddrV4) {
 
 TEST_P(DefaultChannelModeTest, LiveGetLocalhostByAddrV6) {
   HostResult result;
-  struct in6_addr addr = in6addr_loopback;
+  struct in6_addr addr;
+  memset(&addr, 0, sizeof(addr));
+  addr.s6_addr[15] = 1;  // in6addr_loopback
   ares_gethostbyaddr(channel_, &addr, sizeof(addr), AF_INET6, HostCallback, &result);
   Process();
   EXPECT_TRUE(result.done_);
@@ -203,7 +205,7 @@ INSTANTIATE_TEST_CASE_P(Modes, DefaultChannelModeTest,
 
 TEST_F(DefaultChannelTest, LiveSearchA) {
   SearchResult result;
-  ares_search(channel_, "www.facebook.com.", ns_c_in, ns_t_a,
+  ares_search(channel_, "www.youtube.com.", ns_c_in, ns_t_a,
               SearchCallback, &result);
   Process();
   EXPECT_TRUE(result.done_);
